summaryrefslogtreecommitdiff
path: root/include/apr_getopt.h
diff options
context:
space:
mode:
authordougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2001-02-08 07:45:23 +0000
committerdougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2001-02-08 07:45:23 +0000
commitaba88e6ebce8d24a8ca387c28aabc9f17559a56c (patch)
tree136752321dd3e22c22463c9ab35a700ab0507729 /include/apr_getopt.h
parent482ce86a79d41d751123dcfcfc29f4098135c4b7 (diff)
downloadlibapr-aba88e6ebce8d24a8ca387c28aabc9f17559a56c.tar.gz
renaming various functions for consistency sake
see: http://apr.apache.org/~dougm/apr_rename.pl PR: Obtained from: Submitted by: Reviewed by: git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@61194 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_getopt.h')
-rw-r--r--include/apr_getopt.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/apr_getopt.h b/include/apr_getopt.h
index 404b7e77a..f05a1e1e6 100644
--- a/include/apr_getopt.h
+++ b/include/apr_getopt.h
@@ -115,14 +115,14 @@ struct apr_getopt_option_t {
* @param argc The number of arguments to parse
* @param argv The array of arguments to parse
* @tip Arguments 2 and 3 are most commonly argc and argv from main(argc, argv)
- * @deffunc apr_status_t apr_initopt(apr_getopt_t **os, apr_pool_t *cont,int argc, char *const *argv)
+ * @deffunc apr_status_t apr_getopt_init(apr_getopt_t **os, apr_pool_t *cont,int argc, char *const *argv)
*/
-APR_DECLARE(apr_status_t) apr_initopt(apr_getopt_t **os, apr_pool_t *cont,
+APR_DECLARE(apr_status_t) apr_getopt_init(apr_getopt_t **os, apr_pool_t *cont,
int argc, const char * const *argv);
/**
* Parse the options initialized by apr_initopt().
* @param os The apr_opt_t structure returned by apr_initopt()
* @param opts A string of characters that are acceptable options to the
* program. Characters followed by ":" are required to have an
* option associated
@@ -141,10 +141,10 @@ APR_DECLARE(apr_status_t) apr_getopt(apr_getopt_t *os, const char *opts,
char *optch, const char **optarg);
/**
* Parse the options initialized by apr_initopt(), accepting long
* options beginning with "--" in addition to single-character
* options beginning with "-".
- * @param os The apr_getopt_t structure created by apr_initopt()
+ * @param os The apr_getopt_t structure created by apr_getopt_init()
* @param opts A pointer to a list of apr_getopt_option_t structures, which
* can be initialized with { "name", optch, has_args }. has_args
* is nonzero if the option requires an argument. A structure
@@ -115,14 +115,14 @@ struct apr_getopt_option_t {
int argc, const char * const *argv);
/**
- * Parse the options initialized by apr_initopt().
- * @param os The apr_opt_t structure returned by apr_initopt()
+ * Parse the options initialized by apr_getopt_init().
+ * @param os The apr_opt_t structure returned by apr_getopt_init()
* @param opts A string of characters that are acceptable options to the
* program. Characters followed by ":" are required to have an
@@ -141,10 +141,10 @@ APR_DECLARE(apr_status_t) apr_getopt(apr_getopt_t *os, const char *opts,
char *optch, const char **optarg);
/**
- * Parse the options initialized by apr_initopt(), accepting long
+ * Parse the options initialized by apr_getopt_init(), accepting long
* options beginning with "--" in addition to single-character
* options beginning with "-".